pub fn default_label_formatter(pos: &HoverPosition<'_>) -> Option<String>Expand description
Default label formatter that shows the x and y coordinates with 3 decimal places.
pub fn default_label_formatter(pos: &HoverPosition<'_>) -> Option<String>Default label formatter that shows the x and y coordinates with 3 decimal places.