pub struct HLine { /* private fields */ }Expand description
A horizontal line in a plot, filling the full width
Implementations
Sourceimpl HLine
impl HLine
pub fn new(name: impl Into<String>, y: impl Into<f64>) -> Self
Sourcepub fn color(self, color: impl Into<Color32>) -> Self
pub fn color(self, color: impl Into<Color32>) -> Self
Stroke color. Default is Color32::TRANSPARENT which means a color will
be auto-assigned.
Sourcepub fn style(self, style: LineStyle) -> Self
pub fn style(self, style: LineStyle) -> Self
Set the line’s style. Default is LineStyle::Solid.
Sourcepub fn name(self, name: impl ToString) -> Self
pub fn name(self, name: impl ToString) -> Self
Name of this plot item.
This name will show up in the plot legend, if legends are turned on.
Setting the name via this method does not change the item’s id, so you
can use it to change the name dynamically between frames without
losing the item’s state. You should make sure the name passed to
Self::new is unique and stable for each item, or set unique and
stable ids explicitly via Self::id.
Sourcepub fn highlight(self, highlight: bool) -> Self
pub fn highlight(self, highlight: bool) -> Self
Highlight this plot item, typically by scaling it up.
If false, the item may still be highlighted via user interaction.
Sourcepub fn allow_hover(self, hovering: bool) -> Self
pub fn allow_hover(self, hovering: bool) -> Self
Allowed hovering this item in the plot. Default: true.