pub struct Line<'a> { /* private fields */ }Expand description
A series of values forming a path.
Implementations
Sourceimpl<'a> Line<'a>
impl<'a> Line<'a>
pub fn new(name: impl Into<String>, series: impl Into<PlotPoints<'a>>) -> Self
Sourcepub fn gradient_color(
self,
callback: Arc<dyn Fn(PlotPoint) -> Color32 + Send + Sync>,
gradient_fill: bool,
) -> Self
pub fn gradient_color( self, callback: Arc<dyn Fn(PlotPoint) -> Color32 + Send + Sync>, gradient_fill: bool, ) -> Self
Add an optional gradient color to the stroke using a callback. The
callback receives a PlotPoint as input with the current X and Y
values and should return a Color32 to be used as the stroke color
for that point.
Setting the gradient_fill parameter to true will use the gradient
color callback for the fill area as well when fill() is set.
Sourcepub fn color(self, color: impl Into<Color32>) -> Self
pub fn color(self, color: impl Into<Color32>) -> Self
Stroke color. Default is Color32::TRANSPARENT which means a color will
be auto-assigned.
Sourcepub fn fill(self, y_reference: f32) -> Self
pub fn fill(self, y_reference: f32) -> Self
Fill the area between this line and a given horizontal reference line.
Sourcepub fn fill_alpha(self, alpha: f32) -> Self
pub fn fill_alpha(self, alpha: f32) -> Self
Set the fill area’s alpha channel. Default is 0.05.
Sourcepub fn style(self, style: LineStyle) -> Self
pub fn style(self, style: LineStyle) -> Self
Set the line’s style. Default is LineStyle::Solid.
Sourcepub fn name(self, name: impl ToString) -> Self
pub fn name(self, name: impl ToString) -> Self
Name of this plot item.
This name will show up in the plot legend, if legends are turned on.
Setting the name via this method does not change the item’s id, so you
can use it to change the name dynamically between frames without
losing the item’s state. You should make sure the name passed to
Self::new is unique and stable for each item, or set unique and
stable ids explicitly via Self::id.
Sourcepub fn highlight(self, highlight: bool) -> Self
pub fn highlight(self, highlight: bool) -> Self
Highlight this plot item, typically by scaling it up.
If false, the item may still be highlighted via user interaction.
Sourcepub fn allow_hover(self, hovering: bool) -> Self
pub fn allow_hover(self, hovering: bool) -> Self
Allowed hovering this item in the plot. Default: true.