Polygon

Struct Polygon 

pub struct Polygon<'a> { /* private fields */ }
A convex polygon.

Implementations

Source

impl<'a> Polygon<'a>

pub fn new(name: impl Into<String>, series: impl Into<PlotPoints<'a>>) -> Self

pub fn stroke(self, stroke: impl Into<Stroke>) -> Self

Add a custom stroke.

pub fn width(self, width: impl Into<f32>) -> Self

Set the stroke width.

pub fn fill_color(self, color: impl Into<Color32>) -> Self

Fill color. Defaults to the stroke color with added transparency.

pub fn style(self, style: LineStyle) -> Self

Set the outline’s style. Default is LineStyle::Solid.

pub fn name(self, name: impl ToString) -> Self

Name of this plot item.

This name will show up in the plot legend, if legends are turned on.

Setting the name via this method does not change the item’s id, so you can use it to change the name dynamically between frames without losing the item’s state. You should make sure the name passed to Self::new is unique and stable for each item, or set unique and stable ids explicitly via Self::id.

pub fn highlight(self, highlight: bool) -> Self

Highlight this plot item, typically by scaling it up.

If false, the item may still be highlighted via user interaction.

pub fn allow_hover(self, hovering: bool) -> Self

Allowed hovering this item in the plot. Default: true.

pub fn id(self, id: impl Into<Id>) -> Self

Sets the id of this plot item.

By default the id is determined from the name passed to Self::new, but it can be explicitly set to a different value.